==> shadow-cljs-2.8.14.jar: shadow/cljs/devtools/server/fake_piggieback04.clj <==
(ns shadow.cljs.devtools.server.fake-piggieback04)

;; tools like cider-nrepl expect to use piggieback
;; but piggieback does a lot of weird things that we neither want or need
;; so this makes it look like we are using piggieback but instead just does nothing

;; https://github.com/cemerick/piggieback/blob/master/src/cemerick/piggieback.clj
;; https://github.com/clojure-emacs/cider-nrepl/blob/master/src/cider/nrepl/middleware/util/cljs.clj

(ns cemerick.piggieback
  (:require [nrepl.middleware]
            [shadow.cljs.devtools.api :as api]))

;; tools access this directly via resolve
(def ^:dynamic *cljs-compiler-env* nil)

;; vim-fireplace calls this directly with a repl-env
;; can only configure which repl-env to use
;; :Piggieback (adzerk.boot-cljs-repl/repl-env)
;; so we just take a keyword?
;; :Piggieback :build-id
(defn cljs-repl [repl-env & options]
  {:pre [(keyword? repl-env)]}
  (api/nrepl-select repl-env))

(defn wrap-cljs-repl [next]
  (fn [{:keys [session] :as msg}]
    (when-not (contains? @session #'*cljs-compiler-env*)
      (swap! session assoc
        #'*cljs-compiler-env* *cljs-compiler-env*))
    (next msg)))

(ns cider.piggieback
  (:require [nrepl.middleware]
            [shadow.cljs.devtools.api :as api]))

;; tools access this directly via resolve
(def ^:dynamic *cljs-compiler-env* nil)

;; vim-fireplace calls this directly with a repl-env
;; can only configure which repl-env to use
;; :Piggieback (adzerk.boot-cljs-repl/repl-env)
;; so we just take a keyword?
;; :Piggieback :build-id
(defn cljs-repl [repl-env & options]
  {:pre [(keyword? repl-env)]}
  (api/nrepl-select repl-env))

(defn wrap-cljs-repl [next]
  (fn [{:keys [session] :as msg}]
    (when-not (contains? @session #'*cljs-compiler-env*)
      (swap! session assoc
        #'*cljs-compiler-env* *cljs-compiler-env*))
    (next msg)))

==> shadow-cljs-2.8.30.jar: shadow/cljs/devtools/server/fake_piggieback04.clj <==
(ns shadow.cljs.devtools.server.fake-piggieback04)

;; tools like cider-nrepl expect to use piggieback
;; but piggieback does a lot of weird things that we neither want or need
;; so this makes it look like we are using piggieback but instead just does nothing

;; https://github.com/cemerick/piggieback/blob/master/src/cemerick/piggieback.clj
;; https://github.com/clojure-emacs/cider-nrepl/blob/master/src/cider/nrepl/middleware/util/cljs.clj

(ns cemerick.piggieback
  (:require [nrepl.middleware]
            [shadow.cljs.devtools.api :as api]))

;; tools access this directly via resolve
(def ^:dynamic *cljs-compiler-env* nil)

;; vim-fireplace calls this directly with a repl-env
;; can only configure which repl-env to use
;; :Piggieback (adzerk.boot-cljs-repl/repl-env)
;; so we just take a keyword?
;; :Piggieback :build-id
(defn cljs-repl [repl-env & options]
  {:pre [(keyword? repl-env)]}
  (api/nrepl-select repl-env))

(defn wrap-cljs-repl [next]
  (fn [{:keys [session] :as msg}]
    (when-not (contains? @session #'*cljs-compiler-env*)
      (swap! session assoc
        #'*cljs-compiler-env* *cljs-compiler-env*))
    (next msg)))

(ns cider.piggieback
  (:require [nrepl.middleware]
            [shadow.jvm-log :as log]
            [shadow.cljs.devtools.api :as api]))

;; tools access this directly via resolve
(def ^:dynamic *cljs-compiler-env* nil)

;; vim-fireplace calls this directly with a repl-env
;; can only configure which repl-env to use
;; :Piggieback (adzerk.boot-cljs-repl/repl-env)
;; so we just take a keyword?
;; :Piggieback :build-id
(defn cljs-repl [repl-env & options]
  {:pre [(keyword? repl-env)]}
  (api/nrepl-select repl-env))

(defn wrap-cljs-repl [next]
  (fn [{:keys [session] :as msg}]
    (when-not (contains? @session #'*cljs-compiler-env*)
      (swap! session assoc
        #'*cljs-compiler-env* *cljs-compiler-env*))
    (next msg)))

(try
  (nrepl.middleware/set-descriptor! #'wrap-cljs-repl
    {:requires #{"clone"}
     ;; piggieback unconditionally hijacks eval and load-file
     :expects #{"eval" "load-file"}
     :handles {}})
  (catch Exception e
    (log/warn-ex e ::set-descriptor)
    ))
